@@ -1,13 +1,11 @@
-extern crate lambda_runtime as lambda;
-extern crate log;
-extern crate serde_derive;
-extern crate simple_logger;
-
-use lambda::{error::HandlerError, lambda};
-use log::error;
-use serde_derive::{Deserialize, Serialize};
 use std::error::Error;
 
+use lambda_runtime::{error::HandlerError, lambda, Context};
+use log::{self, error};
+use serde_derive::{Deserialize, Serialize};
+use simple_error::bail;
+use simple_logger;
+
 #[derive(Deserialize)]
 struct CustomEvent {
     #[serde(rename = "firstName")]
@@ -20,16 +18,16 @@ struct CustomOutput {
 }
 
 fn main() -> Result<(), Box<dyn Error>> {
-    simple_logger::init_with_level(log::Level::Debug).unwrap();
+    simple_logger::init_with_level(log::Level::Debug)?;
     lambda!(my_handler);
 
     Ok(())
 }
 
-fn my_handler(e: CustomEvent, c: lambda::Context) -> Result<CustomOutput, HandlerError> {
+fn my_handler(e: CustomEvent, c: Context) -> Result<CustomOutput, HandlerError> {
     if e.first_name == "" {
         error!("Empty first name in request {}", c.aws_request_id);
-        return Err(c.new_error("Empty first name"));
+        bail!("Empty first name");
     }
 
     Ok(CustomOutput {
